==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSplitPaneUI__24KeyboardHomeHandler.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneUI$KeyboardHomeHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2e8a817f8a70958d javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method$_init$985a59fb314729a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicSplitPaneUI__24KeyboardHomeHandler.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneUI$KeyboardHomeHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2e8a817f8a70958d javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method$_init$985a59fb314729a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardHomeHandler_H_ */
